/****************************************************************************
**  CUBE        http://www.score-p.org/                                    **
**  SCALASCA    http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2015                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/
#ifndef __ASSIGNMENT_EVALUATION_CPP
#define __ASSIGNMENT_EVALUATION_CPP 0

#include "CubeAssignmentEvaluation.h"
#include "CubeStringEvaluation.h"

using namespace cube;
using namespace std;

AssignmentEvaluation::~AssignmentEvaluation()
{
    delete value;
    delete index;
}

double
AssignmentEvaluation::eval()
{
    if ( !value->isString() )
    {
        memory->put( variable, index->eval(), value->eval(), kind );
    }
    else
    {
        memory->put( variable, index->eval(), ( dynamic_cast<StringEvaluation*>( value ) )->strEval(), kind );
    }
    return 0.;
}



double
AssignmentEvaluation::eval( Cnode* cnode, CalculationFlavour cf, Sysres* sr, CalculationFlavour tf  )
{
    if (  !value->isString() )
    {
        memory->put( variable, index->eval( cnode, cf, sr, tf ), value->eval( cnode, cf, sr, tf ), kind  );
    }
    else
    {
        memory->put( variable, index->eval( cnode, cf, sr, tf ), ( dynamic_cast<StringEvaluation*>( value ) )->strEval(), kind  );
    }
    return 0.;
};



double
AssignmentEvaluation::eval( Cnode* cnode, CalculationFlavour cf )
{
    if (  !value->isString() )
    {
        memory->put( variable, index->eval( cnode, cf ), value->eval( cnode, cf ), kind  );
    }
    else
    {
        memory->put( variable, index->eval( cnode, cf ), ( dynamic_cast<StringEvaluation*>( value ) )->strEval(), kind  );
    }
    return 0.;
};


double
AssignmentEvaluation::eval( double arg1, double arg2 )
{
    if (  !value->isString() )
    {
        memory->put( variable, index->eval( arg1, arg2 ), value->eval( arg1, arg2 ), kind  );
    }
    else
    {
        memory->put( variable, index->eval(  arg1, arg2 ), ( dynamic_cast<StringEvaluation*>( value ) )->strEval(), kind  );
    }
    return 0.;
};



double*
AssignmentEvaluation::eval_row( Cnode*             cnode,
                                CalculationFlavour cf )
{
    if (  !value->isString() )
    {
        double* _tmp = value->eval_row( cnode, cf );
        memory->put( variable, index->eval( cnode, cf ), _tmp, kind  );
    }
    return NULL;
}




#endif
